@@ -33,8 +33,8 @@ MYSQL_USER = 'tjlh'
 MYSQL_PASSWORD = 'tjXx^Egw3NdnLK'
 
 # -----------------------------------------------------------------------------------------
-LOGFLAG = True
-# LOGFLAG = False
+# LOGFLAG = True
+LOGFLAG = False
 
 
 
