@@ -101,7 +101,10 @@ freq_1m_sim = \
       '01:21:00', '01:22:00', '01:23:00', '01:24:00', '01:25:00', '01:26:00', '01:27:00', '01:28:00', '01:29:00', '01:30:00',
       '01:31:00', '01:32:00', '01:33:00', '01:34:00', '01:35:00', '01:36:00', '01:37:00', '01:38:00', '01:39:00', '01:40:00',
       '01:41:00', '01:42:00', '01:43:00', '01:44:00', '01:45:00', '01:46:00', '01:47:00', '01:48:00', '01:49:00', '01:50:00',
-      '01:51:00', '01:52:00', '01:53:00', '01:54:00', '01:55:00', '01:56:00', '01:57:00', '01:58:00', '01:59:00',
+      '01:51:00', '01:52:00', '01:53:00', '01:54:00', '01:55:00', '01:56:00', '01:57:00', '01:58:00', '01:59:00', '02:00:00',
+      '02:01:00', '02:02:00', '02:03:00', '02:04:00', '02:05:00', '02:06:00', '02:07:00', '02:08:00', '02:09:00', '02:10:00',
+      '02:11:00', '02:12:00', '02:13:00', '02:14:00', '02:15:00', '02:16:00', '02:17:00', '02:18:00', '02:19:00', '02:20:00',
+      '02:21:00', '02:22:00', '02:23:00', '02:24:00', '02:25:00', '02:26:00', '02:27:00', '02:28:00', '02:29:00',
 
       # '09:00:00',
       '09:01:00', '09:02:00', '09:03:00', '09:04:00', '09:05:00', '09:06:00', '09:07:00', '09:08:00', '09:09:00', '09:10:00',
@@ -484,6 +487,36 @@ freq_10s_sim = \
   '01:57:00', '01:57:10', '01:57:20', '01:57:30', '01:57:40', '01:57:50',
   '01:58:00', '01:58:10', '01:58:20', '01:58:30', '01:58:40', '01:58:50',
   '01:59:00', '01:59:10', '01:59:20', '01:59:30', '01:59:40', '01:59:50',
+  '02:00:00', '02:00:10', '02:00:20', '02:00:30', '02:00:40', '02:00:50',
+  '02:01:00', '02:01:10', '02:01:20', '02:01:30', '02:01:40', '02:01:50',
+  '02:02:00', '02:02:10', '02:02:20', '02:02:30', '02:02:40', '02:02:50',
+  '02:03:00', '02:03:10', '02:03:20', '02:03:30', '02:03:40', '02:03:50',
+  '02:04:00', '02:04:10', '02:04:20', '02:04:30', '02:04:40', '02:04:50',
+  '02:05:00', '02:05:10', '02:05:20', '02:05:30', '02:05:40', '02:05:50',
+  '02:06:00', '02:06:10', '02:06:20', '02:06:30', '02:06:40', '02:06:50',
+  '02:07:00', '02:07:10', '02:07:20', '02:07:30', '02:07:40', '02:07:50',
+  '02:08:00', '02:08:10', '02:08:20', '02:08:30', '02:08:40', '02:08:50',
+  '02:09:00', '02:09:10', '02:09:20', '02:09:30', '02:09:40', '02:09:50',
+  '02:10:00', '02:10:10', '02:10:20', '02:10:30', '02:10:40', '02:10:50',
+  '02:11:00', '02:11:10', '02:11:20', '02:11:30', '02:11:40', '02:11:50',
+  '02:12:00', '02:12:10', '02:12:20', '02:12:30', '02:12:40', '02:12:50',
+  '02:13:00', '02:13:10', '02:13:20', '02:13:30', '02:13:40', '02:13:50',
+  '02:14:00', '02:14:10', '02:14:20', '02:14:30', '02:14:40', '02:14:50',
+  '02:15:00', '02:15:10', '02:15:20', '02:15:30', '02:15:40', '02:15:50',
+  '02:16:00', '02:16:10', '02:16:20', '02:16:30', '02:16:40', '02:16:50',
+  '02:17:00', '02:17:10', '02:17:20', '02:17:30', '02:17:40', '02:17:50',
+  '02:18:00', '02:18:10', '02:18:20', '02:18:30', '02:18:40', '02:18:50',
+  '02:19:00', '02:19:10', '02:19:20', '02:19:30', '02:19:40', '02:19:50',
+  '02:20:00', '02:20:10', '02:20:20', '02:20:30', '02:20:40', '02:20:50',
+  '02:21:00', '02:21:10', '02:21:20', '02:21:30', '02:21:40', '02:21:50',
+  '02:22:00', '02:22:10', '02:22:20', '02:22:30', '02:22:40', '02:22:50',
+  '02:23:00', '02:23:10', '02:23:20', '02:23:30', '02:23:40', '02:23:50',
+  '02:24:00', '02:24:10', '02:24:20', '02:24:30', '02:24:40', '02:24:50',
+  '02:25:00', '02:25:10', '02:25:20', '02:25:30', '02:25:40', '02:25:50',
+  '02:26:00', '02:26:10', '02:26:20', '02:26:30', '02:26:40', '02:26:50',
+  '02:27:00', '02:27:10', '02:27:20', '02:27:30', '02:27:40', '02:27:50',
+  '02:28:00', '02:28:10', '02:28:20', '02:28:30', '02:28:40', '02:28:50',
+  '02:29:00', '02:29:10', '02:29:20', '02:29:30', '02:29:40', '02:29:50',
 
   '09:00:00', '09:00:10', '09:00:20', '09:00:30', '09:00:40', '09:00:50',
   '09:01:00', '09:01:10', '09:01:20', '09:01:30', '09:01:40', '09:01:50',
